==> guikachu-1.1.2.tar.gz: guikachu-1.1.2/src/dialog-win.h <==
//$Id: dialog-win.h,v 1.12 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_DIALOG_WIN_H
#define GUIKACHU_DIALOG_WIN_H

namespace Guikachu
{
    namespace GUI
    {
	class DialogWindow;
    }
}

#include "dialog-res.h"

#include <gtk--/window.h>
#include <gtk--/optionmenu.h>

namespace Guikachu
{
    namespace GUI
    {
	class DialogWindow: public SigC::Object
	{
	    Resources::Dialog   *res;
	    
	    Gtk::Window          window;
	    
	    Gtk::OptionMenu      type_combo;
	public:
	    DialogWindow (Resources::Dialog *res_);
	    void show ();
	private:
	    int delete_event_impl (GdkEventAny *e);
	    void update ();

	    void type_menu_cb (Resources::DialogType type);
	    bool update_block;
	};
    };
};

#endif /* !GUIKACHU_DIALOG_WIN_H */

==> guikachu-1.3.0.tar.gz: guikachu-1.3.0/src/dialog-win.h <==
//$Id: dialog-win.h,v 1.13 2002/06/07 23:40:18 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_DIALOG_WIN_H
#define GUIKACHU_DIALOG_WIN_H

namespace Guikachu
{
    namespace GUI
    {
	class DialogWindow;
    }
}

#include "dialog-res.h"

#include <gtk--/window.h>
#include <gtk--/optionmenu.h>

namespace Guikachu
{
    namespace GUI
    {
	class DialogWindow: public SigC::Object
	{
	    Resources::Dialog   *res;
	    
	    Gtk::Window          window;
	    
	    Gtk::OptionMenu      type_combo;
	public:
	    DialogWindow (Resources::Dialog *res_);
	    void show ();
	private:
	    int delete_event_impl (GdkEventAny *e);
	    void update ();

	    void type_menu_cb (Resources::Dialog::DialogType type);
	    bool update_block;
	};
    };
};

#endif /* !GUIKACHU_DIALOG_WIN_H */
